/*******************
Ad Format: Page Peel
Amazon Template Version: 1.0.0
Last Updated On: 2021-08-31
*******************/

/*******************
VARIABLES
*******************/
var dimensions;
var scrollPos = {
	x: 0,
	y: 0
};

var expansionDiv;
var previewIconDiv;
var closeButton;
var userActionButton;
var clickthroughButton;
var videoContainer;
var video;
var isIOS = false;
var adId, rnd, uid;
var trackInteraction = false;

//if its true, if you change the position in the panel settings in the platform
//automatically will change the position in the Ad
var automaticPeelTabPosition = true;


/*******************
INITIALIZATION
*******************/
function checkIfAdKitReady(event) {
	try {
        initializeCreative();
	}
	catch(e) {}
	adkit.onReady(initializeCreative);
}

function initializeCreative(event) {
	try{
		// so messaging can work in safe frames we need to bind the events that are present in the event manager.
		EBG.pm.bind("sendCreativeId", function () {
			eventManager.apply(this, arguments);
		}, this);
		EBG.pm.bind("eventCallback", function () {
			eventManager.apply(this, arguments);
		}, this);
	}
	catch(error) {
	}

	initializeGlobalVariables();
	displayDimensions();
	addEventListeners();

}

function initializeGlobalVariables() {
	adId = EB._adConfig.adId;
	rnd = EB._adConfig.rnd;
	uid = EB._adConfig.uid;

	previewIconDiv = document.getElementById("preview_icon");
	expansionDiv = document.getElementById("amz_main");
	closeButton = document.getElementById("close_btn");
	localPreviewPeel = document.getElementById("local_preview_peel");
	dimensions = document.getElementById("dimensions"); //for testing only, show the dimensions and scrollpos of the parent
	userActionButton = document.getElementById("user_action_btn");
	clickthroughButton = document.getElementById("cta_btn");
	clickthroughHotspot = document.getElementById("overlay_hotspot");
	videoContainer = document.getElementById("video_container");
	video = document.getElementById("video");
	
     showContent();
		showVideo();
	trackVideoInteractions(video);

	EB.API.setStyle(videoContainer, {
		display: "block"
	});
}


function addEventListeners() {
	closeButton.addEventListener("click", handleCloseButtonClick);
	userActionButton.addEventListener("click", handleUserActionButtonClick);
	clickthroughButton.addEventListener("click", handleClickthroughButtonClick);
	clickthroughHotspot.addEventListener("click", handleClickthroughButtonClick);
}

/*******************
EVENT HANDLERS
*******************/
function handleExpandButtonClick() {
	// to expand a specific panel
	EB.expand({
		panelName: "expand"
	});
	// to expand default panel
	// EB.expand();
}

function handleCloseButtonClick() {
	stopVideo(true); // stop video playing
	EB.userActionCounter("userClick_closeButton");
	sendMessage("retractPeelTab", {uid:uid}); // retract peel tab
}

function handleUserActionButtonClick() {
	EB.userActionCounter("CustomInteraction");
}

function handleClickthroughButtonClick() {
	stopVideo(); // stop video playing
	EB.clickthrough();
}

function onPageScroll(event) {
	scrollPos.x = event.scrollXPercent;
	scrollPos.y = event.scrollYPercent;
	displayDimensions();
}

/*******************
CREATIVE FUNCTIONS
*******************/

function doBeforeFullyPeelOff() {
	showContent();
	showVideo();
}

function doAfterFullyPeelOff(event) {                   
	if(trackInteraction===false && 	!event.isAutoExpand){
		trackInteraction=true;
		if(!event.isAutoExpand){
			EB.userActionCounter("user_PeelOff");																																								                   
		}
	}
	EB.API.setStyle(previewIconDiv, {
		display: "none"   
	});

}

function doBeforePeelTabRetract() {
	EB.API.setStyle(previewIconDiv, {
		display: "block"
	});
}

function doAfterPeelTabRetract() {
	hideContent();
	hideVideo();
	trackInteraction=false;
}

function peelTabPosition(event){
	if(automaticPeelTabPosition){
		//restart position
		EB.API.setStyle(previewIconDiv, {
			bottom: "initial",
			left: "initial",
			top: "initial",
			right: "initial"
		});

		switch(event.position){
			case "topLeft":
				EB.API.setStyle(previewIconDiv, {
					top: "2px",
					left: "2px"
				});
			break;
			case "topRight":
				EB.API.setStyle(previewIconDiv, {
					top: "2px",
					right: "2px"
				});
			break;
			case "bottomRight":
				EB.API.setStyle(previewIconDiv, {
					bottom: "2px",
					right: "2px"
				});
			break;
			case "bottomLeft":
			default:
				EB.API.setStyle(previewIconDiv, {
					bottom: "2px",
					left: "2px"
				});
			break;
		}
	}
}

function showContent() {
	EB.API.setStyle(closeButton, {
		display: "block"
	});
}

function hideContent() {
	EB.API.setStyle(closeButton, {
		display: "none"
	});
}

function stopVideo(rewind) {
	if(video) {
		video.pause();
		if(rewind) {
			video.load();
		}
	}
}

function showVideo() {
	EB.API.setStyle(video, {
		display: "block"
	});
}

function hideVideo() {
	EB.API.setStyle(video, {
		display: "none"
	});
}

/*******************
UTILITIES
*******************/

function trackVideoInteractions(video) {
	var videoTrackingModule = new EBG.VideoModule(video);
}

function displayDimensions() {
	if(dimensions) {
		var iw = window.innerWidth,
			ih = window.innerHeight,
			sx = scrollPos.x,
			sy = scrollPos.y;
		var str = "<br>Viewport: " + iw + "x" + ih + " | <span style='display:block'>Scroll (X: " + sx + "%; Y: " + sy + "%)</span>";
		dimensions.innerHTML = str;
	}
}

function expand() {
	handleExpandButtonClick();
}

function collapse() {
	handleCloseButtonClick();
}

/*********************************
HTML5 Event System - Do Not Modify
*********************************/
var listenerQueue;
var creativeIFrameId;

function sendMessage(type, data) {

	//note: the message type we're sending is also the name of the function inside
	//		the custom script's messageHandlers object, so the case must match.

	if(!data.type) data.type = type;
	EB._sendMessage(type, data);
}

function addCustomScriptEventListener(eventName, callback, interAd) {
	listenerQueue = listenerQueue || {};
	var data = {
		uid: uid,
		listenerId: Math.ceil(Math.random() * 1000000000),
		eventName: eventName,
		interAd: !!(interAd),
		creativeIFrameId: creativeIFrameId
	};
	sendMessage("addCustomScriptEventListener", data);
	data.callback = callback;
	listenerQueue[data.listenerId] = data;
	return data.listenerId;
}

function dispatchCustomScriptEvent(eventName, params) {
	params = params || {};
	params.uid = uid;
	params.eventName = eventName;
	params.creativeIFrameId = creativeIFrameId;
	sendMessage("dispatchCustomScriptEvent", params);
}

function removeCustomScriptEventListener(listenerId) {
	var params = {
		uid: uid,
		listenerId: listenerId,
		creativeIFrameId: creativeIFrameId
	};

	sendMessage("removeCustomScriptEventListener", params);
	if(listenerQueue[listenerId])
		delete listenerQueue[listenerId];
}

function eventManager(event) {
	var msg;
	if(typeof event == "object" && event.data) {
		msg = JSON.parse(event.data);

	}
	else {
		// this is safe frame.
		msg = {
			type: event.type,
			data: event
		};
	}
	if(msg.type && msg.data && (!uid || (msg.data.uid && msg.data.uid == uid))) {
		switch(msg.type) {
		case "sendCreativeId":	
			if(!uid)uid = EB._adConfig.uid;
			creativeIFrameId = msg.data.creativeIFrameId;
			addCustomScriptEventListener('pageScroll', onPageScroll);
			addCustomScriptEventListener("peelTabPosition", peelTabPosition, false);
			addCustomScriptEventListener("doBeforeFullyPeelOff", doBeforeFullyPeelOff, false);
			addCustomScriptEventListener("doAfterFullyPeelOff", doAfterFullyPeelOff, false);
			addCustomScriptEventListener("doBeforePeelTabRetract", doBeforePeelTabRetract, false);
			addCustomScriptEventListener("doAfterPeelTabRetract", doAfterPeelTabRetract, false);
			sendMessage("dispatchScrollPos", {
				uid: uid
			});
			if(creativeContainerReady)
				setTimeout(creativeContainerReady(),300);
			break;
		case "eventCallback": // Handle Callback
			var list = msg.data.listenerIds;
			var length = list.length;
			for(var i = 0; i < length; i++) {
				try {
					var t = listenerQueue[list[i]];
					if(!t) continue;
					t.callback(msg.data);
				}
				catch(e) {}
			}
			break;
		}
	}
}

window.addEventListener("message", function () {
	try {
		eventManager.apply(this, arguments);
	}
	catch(e) {}
}, false);
/*************************************
End HTML5 Event System - Do Not Modify
*************************************/

window.addEventListener("load", checkIfAdKitReady);